@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #include "internal.h"
@@ -344,6 +344,7 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 		goto prepend_filesystem_name;
 	{
 		struct inode *inode = d_backing_inode(sb->s_root);
+
 		/*
 		 * Use filesystem name if filesystems does not support rename()
 		 * operation.
@@ -411,8 +412,7 @@ static char *cs_get_socket_name(const struct path *path, char * const buffer,
 	if (sk) {
 		snprintf(buffer, buflen,
 			 "socket:[family=%u:type=%u:protocol=%u]",
-			 sk->sk_family, sk->sk_type,
-			 sk->sk_protocol);
+			 sk->sk_family, sk->sk_type, sk->sk_protocol);
 	} else {
 		snprintf(buffer, buflen, "socket:[unknown]");
 	}
@@ -463,12 +463,14 @@ char *cs_realpath(const struct path *path)
 		}
 		inode = d_backing_inode(sb->s_root);
 		/*
-		 * Use local name for "filesystems without rename() operation"
-		 * or "path without vfsmount" or "absolute name is unavailable"
-		 * cases.
+		 * Use local name for "filesystems without rename() operation
+		 * and device file" or "path without vfsmount" or "absolute
+		 * name is unavailable" cases.
 		 */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
-		if (!path->mnt || (inode->i_op && !inode->i_op->rename))
+		if (!path->mnt ||
+		    (inode->i_op && !inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else {
 			/* Get absolute name for the rest. */
@@ -478,12 +480,15 @@ char *cs_realpath(const struct path *path)
 		}
 #elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 9, 0)
 		if (!path->mnt ||
-		    (!inode->i_op->rename && !inode->i_op->rename2))
+		    (!inode->i_op->rename && !inode->i_op->rename2 &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 #else
-		if (!path->mnt || !inode->i_op->rename)
+		if (!path->mnt ||
+		    (!inode->i_op->rename &&
+		     !(sb->s_type->fs_flags & FS_REQUIRES_DEV)))
 			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
