@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #ifndef _LINUX_CAITSITH_H
@@ -78,6 +78,10 @@ struct caitsith_operations {
 	int (*mount_permission)(const char *dev_name, const struct path *path,
 				 const char *type, unsigned long flags,
 				 void *data_page);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+	int (*move_mount_permission) (const struct path *from_path,
+				      const struct path *to_path);
+#endif
 	int (*umount_permission)(struct vfsmount *mnt, int flags);
 
 	_Bool(*lport_reserved) (const u16 port); /* Not implemented. */
@@ -186,6 +190,16 @@ static inline int ccs_mount_permission(const char *dev_name,
 	return func ? func(dev_name, path, type, flags, data_page) : 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+static inline int ccs_move_mount_permission(const struct path *from_path,
+					    const struct path *to_path)
+{
+	int (*func) (const struct path *, const struct path *) =
+		caitsith_ops.move_mount_permission;
+	return func ? func(from_path, to_path) : 0;
+}
+#endif
+
 static inline int ccs_umount_permission(struct vfsmount *mnt, int flags)
 {
 	int (*func)(struct vfsmount *, int)
@@ -413,6 +427,14 @@ static inline int ccs_mount_permission(const char *dev_name,
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+static inline int ccs_move_mount_permission(const struct path *from_path,
+					    const struct path *to_path)
+{
+	return 0;
+}
+#endif
+
 static inline int ccs_umount_permission(struct vfsmount *mnt, int flags)
 {
 	return 0;
