@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #ifndef _LINUX_LSM2CAITSITH_H
@@ -59,6 +59,7 @@ int ccs_path_truncate(const struct path *path);
 int ccs_path_unlink(const struct path *dir, struct dentry *dentry);
 int ccs_sb_mount(const char *dev_name, const struct path *path,
 		 const char *type, unsigned long flags, void *data);
+int ccs_move_mount(const struct path *from_path, const struct path *to_path);
 int ccs_sb_pivotroot(const struct path *old_path, const struct path *new_path);
 #else
 int ccs_path_chmod(struct path *path, umode_t mode);
@@ -101,6 +102,13 @@ static inline int ccs_sb_mount(const char *dev_name, const struct path *path,
 {
 	return 0;
 }
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+static inline int ccs_move_mount(const struct path *from_path,
+				 const struct path *to_path)
+{
+	return 0;
+}
+#endif
 static inline int ccs_sb_umount(struct vfsmount *mnt, int flags)
 {
 	return 0;
