@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2010-2013  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 0.2.3   2018/04/01
+ * Version: 0.2.4   2019/08/20
  */
 
 #include "caitsith.h"
@@ -996,6 +996,22 @@ static int cs_sb_mount(const char *dev_name, const struct path *path,
 	return cs_mount_permission(dev_name, path, type, flags, data_page);
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+/**
+ * cs_move_mount - Check permission for move_mount().
+ *
+ * @from_path: Pointer to "struct path".
+ * @to_path:   Pointer to "struct path".
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+static int cs_move_mount(const struct path *from_path,
+			 const struct path *to_path)
+{
+	return cs_move_mount_permission(from_path, to_path);
+}
+#endif
+
 /**
  * cs_sb_umount - Check permission for umount().
  *
@@ -1059,6 +1075,9 @@ static struct security_hook_list caitsith_hooks[] = {
 	MY_HOOK_INIT(file_ioctl, cs_file_ioctl),
 	MY_HOOK_INIT(sb_pivotroot, cs_sb_pivotroot),
 	MY_HOOK_INIT(sb_mount, cs_sb_mount),
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
+	MY_HOOK_INIT(move_mount, cs_move_mount),
+#endif
 	MY_HOOK_INIT(sb_umount, cs_sb_umount),
 #ifdef CONFIG_SECURITY_PATH
 	MY_HOOK_INIT(path_mknod, cs_path_mknod),
